#  tests for scikit-image-0.14.0-py35h6538335_1 (this is a generated file);
print('===== testing package: scikit-image-0.14.0-py35h6538335_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys
import matplotlib

matplotlib.use('Agg')

import skimage

sys.exit(skimage.test(verbose=True))
#  --- run_test.py (end) ---

print('===== scikit-image-0.14.0-py35h6538335_1 OK =====');
print("import: 'skimage'")
import skimage

